@@ -179,10 +179,15 @@ pub async fn check_valid_if_dna(
 ) -> SysValidationResult<()> {
     match header {
         Header::Dna(_) => {
-            if workspace.is_chain_empty(header.author().clone()).await? {
-                Ok(())
-            } else {
+            if !workspace.is_chain_empty(header.author().clone()).await? {
                 Err(PrevHeaderError::InvalidRoot).map_err(|e| ValidationOutcome::from(e).into())
+            } else if header.timestamp() < workspace.dna_def().origin_time {
+                // If the Dna timestamp is ahead of the origin time, every other header
+                // will be inductively so also due to the prev_header check
+                Err(PrevHeaderError::InvalidRootOriginTime)
+                    .map_err(|e| ValidationOutcome::from(e).into())
+            } else {
+                Ok(())
             }
         }
         _ => Ok(()),
@@ -262,7 +267,7 @@ pub async fn check_app_entry_type(
     // We want to be careful about holding locks open to the conductor api
     // so calls are made in blocks
     let dna_file = conductor
-        .get_dna(dna_hash)
+        .get_dna_file(dna_hash)
         .ok_or_else(|| SysValidationError::DnaMissing(dna_hash.clone()))?;
 
     // Check if the zome is found
@@ -365,9 +370,10 @@ pub fn validate_chain<'iter>(
 ) -> SysValidationResult<()> {
     // Check the chain starts in a valid way.
     let mut last_item = match headers.next() {
-        Some(hh) => {
-            let header = hh.as_content();
-            let hash = hh.as_hash();
+        Some(HeaderHashed {
+            hash,
+            content: header,
+        }) => {
             match persisted_chain_head {
                 Some((prev_hash, prev_seq)) => {
                     check_prev_header_chain(prev_hash, *prev_seq, header)
@@ -387,9 +393,11 @@ pub fn validate_chain<'iter>(
         None => return Ok(()),
     };
 
-    for hh in headers {
-        let header = hh.as_content();
-        let hash = hh.as_hash();
+    for HeaderHashed {
+        hash,
+        content: header,
+    } in headers
+    {
         // Check each item of the chain is valid.
         check_prev_header_chain(last_item.0, last_item.1, header)
             .map_err(ValidationOutcome::from)?;
