@@ -4,15 +4,14 @@ use std::sync::Arc;
 use crate::conductor::p2p_agent_store::all_agent_infos;
 use crate::conductor::p2p_agent_store::exchange_peer_info;
 use crate::conductor::ConductorHandle;
-use crate::core::ribosome::error::RibosomeError;
-use crate::core::ribosome::error::RibosomeResult;
+use crate::sweettest::*;
 use crate::test_utils::host_fn_caller::Post;
 use crate::test_utils::install_app;
 use crate::test_utils::new_zome_call;
 use crate::test_utils::setup_app_with_network;
 use crate::test_utils::wait_for_integration_with_others;
+use futures::StreamExt;
 use hdk::prelude::CellId;
-use hdk::prelude::WasmError;
 use holo_hash::AgentPubKey;
 use holo_hash::HeaderHash;
 use holochain_keystore::AgentPubKeyExt;
@@ -29,70 +28,45 @@ use test_case::test_case;
 use tokio_helper;
 use tracing::debug_span;
 
-const TIMEOUT_ERROR: &'static str = "inner function \'call_create_entry_remotely\' failed: ZomeCallNetworkError(\"Other: timeout\")";
-
 #[test_case(2)]
-// More than 4 can cause hardware with less threads to hang and timeout the
-// test, especially when run in parallel with other tests.
-// This includes CI and many laptops.
-// @todo figure out why we can't have more than 4
-// #[test_case(4)]
-// #[test_case(10)]
-#[ignore = "flaky, seems to randomly fail on ci"]
-fn conductors_call_remote(num_conductors: usize) {
-    let f = async move {
-        observability::test_run().ok();
+#[test_case(4)]
+#[tokio::test(flavor = "multi_thread")]
+async fn conductors_call_remote(num_conductors: usize) {
+    observability::test_run().ok();
+    let (dna, _) = SweetDnaFile::unique_from_test_wasms(vec![TestWasm::Create])
+        .await
+        .unwrap();
+    let mut conductors = SweetConductorBatch::from_standard_config(num_conductors).await;
+    let apps = conductors.setup_app("app", &[dna]).await.unwrap();
+    let cells: Vec<_> = apps
+        .into_inner()
+        .into_iter()
+        .map(|c| c.into_cells().into_iter().next().unwrap())
+        .collect();
+    conductors.exchange_peer_info().await;
 
-        let uid = nanoid::nanoid!().to_string();
-        let zomes = vec![TestWasm::Create];
-        let mut network = KitsuneP2pConfig::default();
-        network.transport_pool = vec![kitsune_p2p::TransportConfig::Quic {
-            bind_to: None,
-            override_host: None,
-            override_port: None,
-        }];
-        let handles = setup(zomes, Some(network), num_conductors, uid).await;
+    let agents: Vec<_> = cells.iter().map(|c| c.agent_pubkey().clone()).collect();
 
-        init_all(&handles[..]).await;
-
-        // 100 ms should be enough time to hit another conductor locally.
-        let results = call_each_other(&handles[..], 100).await;
-        for (_, _, result) in results {
-            match result {
-                Some(r) => match r {
-                    Err(RibosomeError::WasmError(WasmError::Guest(e))) => {
-                        assert_eq!(e, TIMEOUT_ERROR)
+    let iter = cells.into_iter().zip(conductors.into_inner().into_iter());
+    futures::stream::iter(iter)
+        .for_each_concurrent(20, |(cell, conductor)| {
+            let agents = agents.clone();
+            async move {
+                for agent in agents {
+                    if agent == *cell.agent_pubkey() {
+                        continue;
                     }
-                    _ => panic!("Unexpected result: {:?}", r),
-                },
-                // None also means a timeout which is what we want before the
-                // agent info is shared
-                None => {}
+                    let _: HeaderHash = conductor
+                        .call(
+                            &cell.zome(TestWasm::Create),
+                            "call_create_entry_remotely_no_rec",
+                            agent,
+                        )
+                        .await;
+                }
             }
-        }
-
-        // Let the remote messages be dropped.
-        // @todo Why??? what messages? why do these messages cause subsequent calls to fail?
-        tokio::time::sleep(std::time::Duration::from_secs(5)).await;
-
-        let mut envs = Vec::with_capacity(handles.len());
-        for h in &handles {
-            let space = h.cell_id.dna_hash().to_kitsune();
-            envs.push(h.get_p2p_env(space));
-        }
-
-        exchange_peer_info(envs).await;
-
-        // Give a little longer timeout here because they must find each other to pass the test
-        // This can require multiple round trips if the head of the source chain keeps moving.
-        // Each time the chain head moves the call must be retried until a clean commit is made.
-        let results = call_each_other(&handles[..], 500).await;
-        for (_, _, result) in results {
-            self::assert_matches!(result, Some(Ok(ZomeCallResponse::Ok(_))));
-        }
-        shutdown(handles).await;
-    };
-    tokio_helper::block_forever_on(f);
+        })
+        .await;
 }
 
 #[test_case(2, 1, 1)]
@@ -390,52 +364,6 @@ async fn init_all(handles: &[TestHandle]) -> Vec<HeaderHash> {
     headers
 }
 
-async fn call_remote(a: TestHandle, b: TestHandle) -> RibosomeResult<ZomeCallResponse> {
-    let invocation = new_zome_call(
-        &a.cell_id,
-        "call_create_entry_remotely",
-        b.cell_id.agent_pubkey().clone(),
-        TestWasm::Create,
-    )
-    .unwrap();
-    a.call_zome(invocation).await.unwrap()
-}
-
-async fn call_each_other(
-    handles: &[TestHandle],
-    timeout: u64,
-) -> Vec<(usize, usize, Option<RibosomeResult<ZomeCallResponse>>)> {
-    let mut results = Vec::with_capacity(handles.len() * 2);
-    for (i, a) in handles.iter().cloned().enumerate() {
-        let mut futures = Vec::with_capacity(handles.len());
-        for (j, b) in handles.iter().cloned().enumerate() {
-            // Don't call self
-            if i == j {
-                continue;
-            }
-            let f = {
-                let a = a.clone();
-                async move {
-                    let f = call_remote(a, b);
-                    // We don't want to wait the maximum network timeout
-                    // in this test as it's a controlled local network
-                    match tokio::time::timeout(std::time::Duration::from_millis(timeout), f).await {
-                        Ok(r) => (i, j, Some(r)),
-                        Err(_) => (i, j, None),
-                    }
-                }
-            };
-            // Run a set of call remotes in parallel.
-            // Can't run everything in parallel or we get chain moved.
-            futures.push(tokio::task::spawn(f));
-        }
-        for f in futures {
-            results.push(f.await.unwrap());
-        }
-    }
-    results
-}
-
 async fn check_gossip(
     handle: &TestHandle,
     all_handles: &[&TestHandle],
@@ -524,6 +452,7 @@ async fn setup(
             name: "conductor_test".to_string(),
             uid,
             properties: SerializedBytes::try_from(()).unwrap(),
+            origin_time: Timestamp::HOLOCHAIN_EPOCH,
             zomes: zomes.clone().into_iter().map(Into::into).collect(),
         },
         zomes.into_iter().map(Into::into),
