@@ -197,8 +197,14 @@ async fn test_network_inner<F>(
 where
     F: Fn(&HolochainP2pEvent) -> bool + Send + 'static,
 {
+    let mut config = holochain_p2p::kitsune_p2p::KitsuneP2pConfig::default();
+    let mut tuning =
+        kitsune_p2p_types::config::tuning_params_struct::KitsuneP2pTuningParams::default();
+    tuning.tx2_implicit_timeout_ms = 500;
+    config.tuning_params = std::sync::Arc::new(tuning);
+
     let (network, mut recv) = spawn_holochain_p2p(
-        holochain_p2p::kitsune_p2p::KitsuneP2pConfig::default(),
+        config,
         holochain_p2p::kitsune_p2p::dependencies::kitsune_p2p_proxy::TlsConfig::new_ephemeral()
             .await
             .unwrap(),
