@@ -170,6 +170,7 @@ impl HostFnCaller {
             cache,
             keystore.clone(),
             Some(cell_id.agent_pubkey().clone()),
+            Arc::new(ribosome.dna_def().as_content().clone()),
         )
         .await
         .unwrap();
@@ -179,7 +180,6 @@ impl HostFnCaller {
             network,
             signal_tx,
             call_zome_handle,
-            cell_id.clone(),
         );
         let ribosome = Arc::new(ribosome);
         let zome = ribosome.dna_def().get_zome(&zome_name).unwrap();
@@ -365,6 +365,7 @@ impl HostFnCaller {
     }
 }
 
+#[macro_export]
 macro_rules! test_entry_impl {
     ($type:ident) => {
         impl TryFrom<$type> for Entry {
